***********************************
The sherpa.astro.utils.xspec module
***********************************

.. currentmodule:: sherpa.astro.utils.xspec

.. automodule:: sherpa.astro.utils.xspec

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      create_xspec_code
      parse_xspec_model_description
